==> Sah-Schemas-Business-ID-NIK-0.001.tar.gz: Sah-Schemas-Business-ID-NIK-0.001/lib/Sah/Schemas/Business/ID/NIK.pm <==
package Sah::Schemas::Business::ID::NIK;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-01-09'; # DATE
our $DIST = 'Sah-Schemas-Business-ID-NIK'; # DIST
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: Sah schemas related to Indonesian NIK numbers

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Business::ID::NIK - Sah schemas related to Indonesian NIK numbers

=head1 VERSION

This document describes version 0.001 of Sah::Schemas::Business::ID::NIK (from Perl distribution Sah-Schemas-Business-ID-NIK), released on 2024-01-09.

=head1 SAH SCHEMAS

The following schemas are included in this distribution:

=over

=item * L<business::id::nik|Sah::Schema::business::id::nik>

Indonesian citizenship registration number (NIK).




=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Business-ID-NIK>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Business-ID-NIK>.

=head1 SEE ALSO

L<Business::ID::NIK>

L<Sah> - schema specification

L<Data::Sah> - Perl implementation of Sah

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Business-ID-NIK>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> Sah-Schemas-Business-ID-NIK-0.002.tar.gz: Sah-Schemas-Business-ID-NIK-0.002/lib/Sah/Schemas/Business/ID/NIK.pm <==
package Sah::Schemas::Business::ID::NIK;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-01-09'; # DATE
our $DIST = 'Sah-Schemas-Business-ID-NIK'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Sah schemas related to Indonesian citizenship registration numbers (NIK)

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Business::ID::NIK - Sah schemas related to Indonesian citizenship registration numbers (NIK)

=head1 VERSION

This document describes version 0.002 of Sah::Schemas::Business::ID::NIK (from Perl distribution Sah-Schemas-Business-ID-NIK), released on 2024-01-09.

=head1 SAH SCHEMAS

The following schemas are included in this distribution:

=over

=item * L<business::id::nik|Sah::Schema::business::id::nik>

Indonesian citizenship registration number (NIK).




=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Business-ID-NIK>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Business-ID-NIK>.

=head1 SEE ALSO

L<Business::ID::NIK>

L<Sah> - schema specification

L<Data::Sah> - Perl implementation of Sah

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Business-ID-NIK>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
